==> dde-daemon_6.0.48.tar.xz: BUILD/misc/ts/org.deepin.dde.accounts.policy/policy_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>ཁྱོད་ཀྱི་སྤྱོད་མཁན་གཞི་གྲངས་བཟོ་བཅོས་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>ཁྱོད་ཀྱི་སྤྱོད་མཁན་གཞི་གྲངས་བཟོ་བཅོས་བྱེད་པ།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>སྤྱོད་མཁན་གཞི་གྲངས་བཟོ་བཅོས་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>སྤྱོད་མཁན་གྱི་རྩིས་ཁྲ་དོ་དམ།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>ཐོ་རང་འཇུག་བྱེད་པར་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>ཐོ་རང་འཇུག་བྱེད་པ།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>ཐོ་རང་འཇུག་སྒོ་རྒྱག་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>ཐོ་རང་འཇུག་སྒོ་རྒྱག་པ།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་པ།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་པ་སྒོ་རྒྱག་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་པ་སྒོ་རྒྱག་པ།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>མཐེབ་གཞོང་བཀོད་པ་སྒྲིག་འགོད་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>མཐེབ་གཞོང་བཀོད་པ་སྒྲིག་འགོད་བྱེད་པ།</translation>
		</message>
	</context>
</TS>

==> dde-daemon_6.1.27.tar.xz: BUILD/misc/ts/org.deepin.dde.accounts.policy/policy_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>ཁྱོད་ཀྱི་སྤྱོད་མཁན་གཞི་གྲངས་བཟོ་བཅོས་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>ཁྱོད་ཀྱི་སྤྱོད་མཁན་གཞི་གྲངས་བཟོ་བཅོས་བྱེད་པ།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>སྤྱོད་མཁན་གཞི་གྲངས་བཟོ་བཅོས་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>སྤྱོད་མཁན་གྱི་རྩིས་ཁྲ་དོ་དམ།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>ཐོ་རང་འཇུག་བྱེད་པར་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>ཐོ་རང་འཇུག་བྱེད་པ།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>ཐོ་རང་འཇུག་སྒོ་རྒྱག་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>ཐོ་རང་འཇུག་སྒོ་རྒྱག་པ།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-quick-login!message" line="0"/>
			<source>Authentication is required to enable quick login</source>
			<translation>འཕྲལ་དུ་ཐོ་འཇུག་པར་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-quick-login!description" line="0"/>
			<source>Enable Quick Login</source>
			<translation>འཕྲུལ་དུ་ཐོ་འཇུག</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-quick-login!message" line="0"/>
			<source>Authentication is required to disable quick login</source>
			<translation>འཕྲལ་དུ་ཐོ་འཇུག་པར་ར་སྤྲོད་བྱེད་མི་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-quick-login!description" line="0"/>
			<source>Disable Quick Login</source>
			<translation>འཕྲུལ་དུ་ཐོ་འཇུག་ཅེས་པ་སྒོ་རྒྱག་པ།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-wechat-auth!message" line="0"/>
			<source>Authentication is required to enable WeChat code login</source>
			<translation>སྐད་འཕྲིན་བཤེར་ནས་ཐོ་འཇུག་པར་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-wechat-auth!description" line="0"/>
			<source>Enable WeChat Code Login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-wechat-auth!message" line="0"/>
			<source>Authentication is required to disable WeChat code login</source>
			<translation>སྐད་འཕྲིན་བཤེར་ནས་ཐོ་འཇུག་པར་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-wechat-auth!description" line="0"/>
			<source>Disable WeChat Code Login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་པ།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་པ་སྒོ་རྒྱག་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་པ་སྒོ་རྒྱག་པ།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>མཐེབ་གཞོང་བཀོད་པ་སྒྲིག་འགོད་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>མཐེབ་གཞོང་བཀོད་པ་སྒྲིག་འགོད་བྱེད་པ།</translation>
		</message>
	</context>
</TS>
